@@ -22,7 +22,7 @@ use SUPER;
 
 # ABSTRACT: ECMAScript-262, Edition 5, lexical program grammar written in Marpa BNF
 
-our $VERSION = '0.010'; # TRIAL VERSION
+our $VERSION = '0.013'; # TRIAL VERSION
 
 our $WhiteSpace        = qr/(?:[\p{MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::CharacterClasses::IsWhiteSpace}])/;
 our $LineTerminator    = qr/(?:[\p{MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::CharacterClasses::IsLineTerminator}])/;
@@ -477,7 +477,7 @@ MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::Program - ECMAScr
 
 =head1 VERSION
 
-version 0.010
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -536,7 +536,7 @@ __DATA__
 #
 :start ::= Program
 :default ::= action => valuesAndRuleId # bless => ::lhs
-lexeme default = action => [start,length,value]
+lexeme default = action => [start,length,value] forgiving => 1 
 
 #
 # Literal definition as per lexical grammar
